# frozen_string_literal: true

require_relative '../command'
require 'tty-command'

module Sutty
  module Cli
    module Commands
      # Genera una plantilla nueva, a partir de sutty-base-jekyll-theme
      # y realiza la configuración inicial del repositorio.
      class Theme < Sutty::Cli::Command
        attr_reader :name

        def initialize(name, options)
          @name = name
          @options = options
        end

        def execute(input: $stdin, output: $stdout)
          cmd.run('git clone https://0xacab.org/sutty/jekyll/sutty-base-jekyll-theme.git', theme_name)

          Dir.chdir theme_name do
            cmd.run('git remote rename origin upstream')
            cmd.run('git remote add origin', origin)
            cmd.run('git push -u origin master')
            cmd.run('git mv sutty-base-jekyll-theme.gemspec', gemspec)
          end
        end

        private

        # @return [String]
        def theme_name
          @theme_name ||= "#{name}-jekyll-theme"
        end

        # @return [String]
        def origin
          @origin ||= "git@0xacab.org:sutty/jekyll/#{theme_name}.git"
        end

        # @return [String]
        def gemspec
          @gemspec ||= "#{theme_name}.gemspec"
        end

        # @return [TTY::Command]
        def cmd
          @cmd ||= TTY::Command.new
        end
      end
    end
  end
end
